//==============================================================================
//         Copyright 2003 - 2012   LASMEA UMR 6602 CNRS/Univ. Clermont II
//         Copyright 2009 - 2012   LRI    UMR 8623 CNRS/Univ Paris Sud XI
//
//          Distributed under the Boost Software License, Version 1.0.
//                 See accompanying file LICENSE.txt or copy at
//                     http://www.boost.org/LICENSE_1_0.txt
//==============================================================================
#ifndef NT2_CORE_CONTAINER_DSL_HPP_INCLUDED
#define NT2_CORE_CONTAINER_DSL_HPP_INCLUDED

#include <nt2/core/container/operators.hpp>
#include <boost/dispatch/dsl/call.hpp>
#include <nt2/core/container/dsl/forward.hpp>
#include <nt2/core/container/dsl/expression.hpp>
#include <nt2/core/container/dsl/grammar.hpp>
#include <nt2/core/container/dsl/domain.hpp>
#include <nt2/core/container/dsl/generator.hpp>
#include <nt2/include/functions/terminal.hpp>
#include <nt2/include/functions/evaluate.hpp>
#include <nt2/include/functions/extent.hpp>
#include <nt2/core/functions/function.hpp>

#endif
